Coverage for ejpiaj/parsers: 0%

# Coverage for ejpiaj/parsers : 0%

## 9 statements 0 run 9 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 | import yaml import json import xmltodict def yaml_parser(filename): return yaml.load(open(filename)) def json_parser(filename): return json.load(open(filename)) def xml_parser(filename): return xmltodict.parse(open(filename))